/* Noto Sans for body and interface components */
html, body, .tooltip, .popover {
  font-family: 'Noto Sans', sans-serif;
}

/* Noto Sans Mono for code and monospaced text */
pre, code, kbd, samp, .text-monospace {
  font-family: 'Noto Sans Mono', monospace;
}
