/* Noto Sans - Regular */
@font-face {
  font-family: 'Noto Sans';
  src: url('woff2/NotoSans-Regular.woff2') format('woff2');
  font-weight: normal;
  font-style: normal;
}

/* Noto Sans - Italic */
@font-face {
  font-family: 'Noto Sans';
  src: url('woff2/NotoSans-Italic.woff2') format('woff2');
  font-weight: normal;
  font-style: italic;
}

/* Noto Sans - Bold */
@font-face {
  font-family: 'Noto Sans';
  src: url('woff2/NotoSans-Bold.woff2') format('woff2');
  font-weight: bold;
  font-style: normal;
}

/* Noto Sans - Bold Italic */
@font-face {
  font-family: 'Noto Sans';
  src: url('woff2/NotoSans-BoldItalic.woff2') format('woff2');
  font-weight: bold;
  font-style: italic;
}

/* Noto Sans Mono - Regular */
@font-face {
  font-family: 'Noto Sans Mono';
  src: url('woff2/NotoSansMono-Regular.woff2') format('woff2');
  font-weight: normal;
  font-style: normal;
}
